# -*- coding: utf-8 -*-

"""Top-level package for wBuild."""

__author__ = """Leonhard Wachutka"""
__email__ = 'leonhard@wachutka.eu'
__version__ = '1.1.5'


from . import autolink
from . import cli
from . import createIndex
from . import scanFiles
from . import syntaxCheckers
from . import utils
